@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
 import os
@@ -10,10 +11,9 @@ import codecs
 import sys
 PY3 = (sys.version_info[0] == 3)
 if PY3:
-    unicode = str
-    basestring = str
+    unicode, basestring = str, str
 
-__version__ = '0.5.2'
+__version__ = '0.5.3'
 __author__ = 'Mahmoud Hashemi'
 __contact__ = 'mahmoudrhashemi@gmail.com'
 __url__ = 'https://github.com/mahmoud/ashes'
@@ -165,10 +165,10 @@ class Tag(Token):
 
     @classmethod
     def from_match(cls, match):
-        kw = dict([(k, v.strip()) for k, v in match.groupdict().items()
-                  if v is not None and v.strip()])
-        kw['text'] = match.group(0)
-        obj = cls(**kw)
+        kw = dict([(str(k), v.strip())
+                   for k, v in match.groupdict().items()
+                   if v is not None and v.strip()])
+        obj = cls(text=match.group(0), **kw)
         obj.orig_match = match
         return obj
 
@@ -240,8 +240,8 @@ def parse_inline(source):
 
 
 def inline_to_dust_ast(tokens):
-    if tokens and isinstance(tokens[0], BufferToken):
-        body = ['literal', tokens[0].text]
+    if tokens and all(isinstance(t, BufferToken) for t in tokens):
+        body = ['literal', ''.join(t.text for t in tokens)]
     else:
         body = ['body']
         for b in tokens:
@@ -1485,7 +1485,7 @@ class BaseAshesEnv(object):
     def _load_template(self, name):
         for loader in self.loaders:
             try:
-                source = loader.load(name)
+                source = loader.load(name, env=self)
             except TemplateNotFound:
                 continue
             else:
@@ -1658,7 +1658,8 @@ else:
                 if key in self.settings:
                     options.setdefault(key, self.settings[key])
             env = self.settings.get('env', default_env)
-
+            # I truly despise 2.6.4's unicode kwarg bug
+            options = dict([(str(k), v) for k, v in options.iteritems()])
             self.tpl = env.register_source(**options)
 
         def _load_source(self, name):
